@@ -7,7 +7,7 @@ use Try::Tiny;
 use Lingua::FreeLing3::Bindings;
 use parent -norequire, 'Lingua::FreeLing3::Bindings::parse_tree';
 
-our $VERSION = "0.01";
+our $VERSION = "0.02";
 
 =encoding UTF-8
 
@@ -58,31 +58,8 @@ Returns the number of childs for this tree node.
 
 =cut
 
-# *nth_child = *Lingua::FreeLing3::Bindingsc::TreeNode_nth_child;
-# *nth_child_ref = *Lingua::FreeLing3::Bindingsc::TreeNode_nth_child_ref;
-# *get_info = *Lingua::FreeLing3::Bindingsc::TreeNode_get_info;
-# *append_child = *Lingua::FreeLing3::Bindingsc::TreeNode_append_child;
-# *hang_child = *Lingua::FreeLing3::Bindingsc::TreeNode_hang_child;
-# *clear = *Lingua::FreeLing3::Bindingsc::TreeNode_clear;
-# *empty = *Lingua::FreeLing3::Bindingsc::TreeNode_empty;
-# *sibling_begin = *Lingua::FreeLing3::Bindingsc::TreeNode_sibling_begin;
-# *sibling_end = *Lingua::FreeLing3::Bindingsc::TreeNode_sibling_end;
-# *begin = *Lingua::FreeLing3::Bindingsc::TreeNode_begin;
-# *end = *Lingua::FreeLing3::Bindingsc::TreeNode_end;
+# inherited
 
-### getInfo returns ::node
-
-##package Lingua::FreeLing3::ParseTreeNode;
-
-# *get_label = *Lingua::FreeLing3::Bindingsc::node_get_label;
-# *get_word = *Lingua::FreeLing3::Bindingsc::node_get_word;
-# *set_word = *Lingua::FreeLing3::Bindingsc::node_set_word;
-# *set_label = *Lingua::FreeLing3::Bindingsc::node_set_label;
-# *is_head = *Lingua::FreeLing3::Bindingsc::node_is_head;
-# *set_head = *Lingua::FreeLing3::Bindingsc::node_set_head;
-# *is_chunk = *Lingua::FreeLing3::Bindingsc::node_is_chunk;
-# *set_chunk = *Lingua::FreeLing3::Bindingsc::node_set_chunk;
-# *get_chunk_ord = *Lingua::FreeLing3::Bindingsc::node_get_chunk_ord;
 
 
 
@@ -114,7 +91,7 @@ Dumps the tree in a textual format, useful for debug purposes.
 sub dump {
     my $tree = shift;
 
-    my $label = $tree->label;
+    my $label = $tree->get_info->get_label;
     $label .= " (". $tree->word->form. ")" unless $tree->num_children;
 
     $label .= "\n";
@@ -152,12 +129,38 @@ freeling library for extra information, or perl(1) itself.
 
 Alberto Manuel Brandão Simões, E<lt>ambs@cpan.orgE<gt>
 
-Jorge Cunha Mendes E<lt>jorgecunhamendes@gmail.comE<gt>
-
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2011-2012 by Projecto Natura
+Copyright (C) 2011-2013 by Projecto Natura
 
 =cut
 
 
+
+
+
+# *nth_child = *Lingua::FreeLing3::Bindingsc::TreeNode_nth_child;
+# *nth_child_ref = *Lingua::FreeLing3::Bindingsc::TreeNode_nth_child_ref;
+# *get_info = *Lingua::FreeLing3::Bindingsc::TreeNode_get_info;
+# *append_child = *Lingua::FreeLing3::Bindingsc::TreeNode_append_child;
+# *hang_child = *Lingua::FreeLing3::Bindingsc::TreeNode_hang_child;
+# *clear = *Lingua::FreeLing3::Bindingsc::TreeNode_clear;
+# *empty = *Lingua::FreeLing3::Bindingsc::TreeNode_empty;
+# *sibling_begin = *Lingua::FreeLing3::Bindingsc::TreeNode_sibling_begin;
+# *sibling_end = *Lingua::FreeLing3::Bindingsc::TreeNode_sibling_end;
+# *begin = *Lingua::FreeLing3::Bindingsc::TreeNode_begin;
+# *end = *Lingua::FreeLing3::Bindingsc::TreeNode_end;
+
+### getInfo returns ::node
+
+##package Lingua::FreeLing3::ParseTreeNode;
+
+# *get_label = *Lingua::FreeLing3::Bindingsc::node_get_label;
+# *get_word = *Lingua::FreeLing3::Bindingsc::node_get_word;
+# *set_word = *Lingua::FreeLing3::Bindingsc::node_set_word;
+# *set_label = *Lingua::FreeLing3::Bindingsc::node_set_label;
+# *is_head = *Lingua::FreeLing3::Bindingsc::node_is_head;
+# *set_head = *Lingua::FreeLing3::Bindingsc::node_set_head;
+# *is_chunk = *Lingua::FreeLing3::Bindingsc::node_is_chunk;
+# *set_chunk = *Lingua::FreeLing3::Bindingsc::node_set_chunk;
+# *get_chunk_ord = *Lingua::FreeLing3::Bindingsc::node_get_chunk_ord;
